@@ -25,16 +25,16 @@ class DeleteContainerAppsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'DeleteContainerApps')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ContainerApps(self):
+	def get_ContainerApps(self): # RepeatList
 		return self.get_query_params().get('ContainerApp')
 
-	def set_ContainerApps(self, ContainerApps):
-		for depth1 in range(len(ContainerApps)):
-			if ContainerApps[depth1].get('Id') is not None:
-				self.add_query_param('ContainerApp.' + str(depth1 + 1) + '.Id', ContainerApps[depth1].get('Id'))
\ No newline at end of file
+	def set_ContainerApps(self, ContainerApp):  # RepeatList
+		for depth1 in range(len(ContainerApp)):
+			if ContainerApp[depth1].get('Id') is not None:
+				self.add_query_param('ContainerApp.' + str(depth1 + 1) + '.Id', ContainerApp[depth1].get('Id'))
