@@ -25,20 +25,19 @@ class ListImagesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ListImages')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_BaseOsTag(self):
+	def get_BaseOsTag(self): # String
 		return self.get_query_params().get('BaseOsTag')
 
-	def set_BaseOsTag(self,BaseOsTag):
-		self.add_query_param('BaseOsTag',BaseOsTag)
-
-	def get_InstanceType(self):
+	def set_BaseOsTag(self, BaseOsTag):  # String
+		self.add_query_param('BaseOsTag', BaseOsTag)
+	def get_InstanceType(self): # String
 		return self.get_query_params().get('InstanceType')
 
-	def set_InstanceType(self,InstanceType):
-		self.add_query_param('InstanceType',InstanceType)
\ No newline at end of file
+	def set_InstanceType(self, InstanceType):  # String
+		self.add_query_param('InstanceType', InstanceType)
