@@ -25,32 +25,29 @@ class ModifyVisualServicePasswdRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'ModifyVisualServicePasswd')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RunasUserPassword(self):
+	def get_RunasUserPassword(self): # String
 		return self.get_query_params().get('RunasUserPassword')
 
-	def set_RunasUserPassword(self,RunasUserPassword):
-		self.add_query_param('RunasUserPassword',RunasUserPassword)
-
-	def get_RunasUser(self):
+	def set_RunasUserPassword(self, RunasUserPassword):  # String
+		self.add_query_param('RunasUserPassword', RunasUserPassword)
+	def get_RunasUser(self): # String
 		return self.get_query_params().get('RunasUser')
 
-	def set_RunasUser(self,RunasUser):
-		self.add_query_param('RunasUser',RunasUser)
-
-	def get_ClusterId(self):
+	def set_RunasUser(self, RunasUser):  # String
+		self.add_query_param('RunasUser', RunasUser)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_Passwd(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_Passwd(self): # String
 		return self.get_query_params().get('Passwd')
 
-	def set_Passwd(self,Passwd):
-		self.add_query_param('Passwd',Passwd)
\ No newline at end of file
+	def set_Passwd(self, Passwd):  # String
+		self.add_query_param('Passwd', Passwd)
