@@ -25,20 +25,19 @@ class UpgradeClientRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'EHPC', '2018-04-12', 'UpgradeClient')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClientVersion(self):
+	def get_ClientVersion(self): # String
 		return self.get_query_params().get('ClientVersion')
 
-	def set_ClientVersion(self,ClientVersion):
-		self.add_query_param('ClientVersion',ClientVersion)
-
-	def get_ClusterId(self):
+	def set_ClientVersion(self, ClientVersion):  # String
+		self.add_query_param('ClientVersion', ClientVersion)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
\ No newline at end of file
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
